@@ -21,6 +21,10 @@
 #include <telepathy-glib/svc-channel.h>
 #include <telepathy-glib/svc-generic.h>
 
+/* This is for text-mixin unit tests, others should be using ExampleEcho2Channel
+ * which uses newer TpMessageMixin */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+
 static void text_iface_init (gpointer iface, gpointer data);
 static void channel_iface_init (gpointer iface, gpointer data);
 
@@ -343,14 +347,14 @@ tp_tests_props_text_channel_class_init (TpTestsPropsTextChannelClass *klass)
 {
   GObjectClass *object_class = (GObjectClass *) klass;
   static TpDBusPropertiesMixinPropImpl channel_props[] = {
-      { "TargetHandleType", (gpointer) "handle-type", NULL },
-      { "TargetHandle", (gpointer) "handle", NULL },
-      { "ChannelType", (gpointer) "channel-type", NULL },
-      { "Interfaces", (gpointer) "interfaces", NULL },
-      { "TargetID", (gpointer) "target-id", NULL },
-      { "Requested", (gpointer) "requested", NULL },
-      { "InitiatorHandle", (gpointer) "initiator-handle", NULL },
-      { "InitiatorID", (gpointer) "initiator-id", NULL },
+      { "TargetHandleType", "handle-type", NULL },
+      { "TargetHandle", "handle", NULL },
+      { "ChannelType", "channel-type", NULL },
+      { "Interfaces", "interfaces", NULL },
+      { "TargetID", "target-id", NULL },
+      { "Requested", "requested", NULL },
+      { "InitiatorHandle", "initiator-handle", NULL },
+      { "InitiatorID", "initiator-id", NULL },
       { NULL }
   };
   static TpDBusPropertiesMixinIfaceImpl prop_interfaces[] = {
@@ -569,3 +573,5 @@ tp_tests_text_channel_get_props (TpTestsTextChannelNull *self)
   g_strfreev (interfaces);
   return props;
 }
+
+G_GNUC_END_IGNORE_DEPRECATIONS
